@@ -36,14 +36,14 @@ test_empty (hb_set_t *s)
   g_assert_cmpint (hb_set_get_population (s), ==, 0);
   g_assert_cmpint (hb_set_get_min (s), ==, HB_SET_VALUE_INVALID);
   g_assert_cmpint (hb_set_get_max (s), ==, HB_SET_VALUE_INVALID);
-  g_assert (!hb_set_has (s, 13));
+  g_assert_true (!hb_set_has (s, 13));
   next = 53043;
-  g_assert (!hb_set_next (s, &next));
+  g_assert_true (!hb_set_next (s, &next));
   g_assert_cmpint (next, ==, HB_SET_VALUE_INVALID);
   next = 07734;
-  g_assert (!hb_set_previous (s, &next));
+  g_assert_true (!hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, HB_SET_VALUE_INVALID);
-  g_assert (hb_set_is_empty (s));
+  g_assert_true (hb_set_is_empty (s));
 }
 
 static void
@@ -54,10 +54,10 @@ test_not_empty (hb_set_t *s)
   g_assert_cmpint (hb_set_get_min (s), !=, HB_SET_VALUE_INVALID);
   g_assert_cmpint (hb_set_get_max (s), !=, HB_SET_VALUE_INVALID);
   next = HB_SET_VALUE_INVALID;
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, !=, HB_SET_VALUE_INVALID);
   next = HB_SET_VALUE_INVALID;
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, !=, HB_SET_VALUE_INVALID);
 }
 
@@ -79,47 +79,47 @@ test_set_basic (void)
 
   hb_set_add_range (s, 10, 29);
   test_not_empty (s);
-  g_assert (hb_set_has (s, 13));
+  g_assert_true (hb_set_has (s, 13));
   g_assert_cmpint (hb_set_get_population (s), ==, 20);
   g_assert_cmpint (hb_set_get_min (s), ==, 10);
   g_assert_cmpint (hb_set_get_max (s), ==, 29);
 
   test_not_empty (s);
-  g_assert (hb_set_has (s, 13));
+  g_assert_true (hb_set_has (s, 13));
   g_assert_cmpint (hb_set_get_population (s), ==, 20);
   g_assert_cmpint (hb_set_get_min (s), ==, 10);
   g_assert_cmpint (hb_set_get_max (s), ==, 29);
 
   hb_set_del_range (s, 10, 18);
   test_not_empty (s);
-  g_assert (!hb_set_has (s, 13));
+  g_assert_true (!hb_set_has (s, 13));
 
   hb_set_add_range (s, 200, 800);
   test_not_empty (s);
-  g_assert (!hb_set_has (s, 100));
-  g_assert (!hb_set_has (s, 199));
-  g_assert (hb_set_has (s, 200));
-  g_assert (hb_set_has (s, 201));
-  g_assert (hb_set_has (s, 243));
-  g_assert (hb_set_has (s, 254));
-  g_assert (hb_set_has (s, 255));
-  g_assert (hb_set_has (s, 256));
-  g_assert (hb_set_has (s, 257));
-  g_assert (hb_set_has (s, 511));
-  g_assert (hb_set_has (s, 512));
-  g_assert (hb_set_has (s, 600));
-  g_assert (hb_set_has (s, 767));
-  g_assert (hb_set_has (s, 768));
-  g_assert (hb_set_has (s, 769));
-  g_assert (hb_set_has (s, 782));
-  g_assert (hb_set_has (s, 798));
-  g_assert (hb_set_has (s, 799));
-  g_assert (hb_set_has (s, 800));
-  g_assert (!hb_set_has (s, 801));
-  g_assert (!hb_set_has (s, 802));
+  g_assert_true (!hb_set_has (s, 100));
+  g_assert_true (!hb_set_has (s, 199));
+  g_assert_true (hb_set_has (s, 200));
+  g_assert_true (hb_set_has (s, 201));
+  g_assert_true (hb_set_has (s, 243));
+  g_assert_true (hb_set_has (s, 254));
+  g_assert_true (hb_set_has (s, 255));
+  g_assert_true (hb_set_has (s, 256));
+  g_assert_true (hb_set_has (s, 257));
+  g_assert_true (hb_set_has (s, 511));
+  g_assert_true (hb_set_has (s, 512));
+  g_assert_true (hb_set_has (s, 600));
+  g_assert_true (hb_set_has (s, 767));
+  g_assert_true (hb_set_has (s, 768));
+  g_assert_true (hb_set_has (s, 769));
+  g_assert_true (hb_set_has (s, 782));
+  g_assert_true (hb_set_has (s, 798));
+  g_assert_true (hb_set_has (s, 799));
+  g_assert_true (hb_set_has (s, 800));
+  g_assert_true (!hb_set_has (s, 801));
+  g_assert_true (!hb_set_has (s, 802));
 
   hb_set_del (s, 800);
-  g_assert (!hb_set_has (s, 800));
+  g_assert_true (!hb_set_has (s, 800));
 
   g_assert_cmpint (hb_set_get_max (s), ==, 799);
 
@@ -152,7 +152,7 @@ static void test_set_intersect_empty (void)
   hb_set_add (b, 24064);
 
   hb_set_intersect (a, b);
-  g_assert (hb_set_is_empty (a));
+  g_assert_true (hb_set_is_empty (a));
 
   hb_set_destroy (a);
   hb_set_destroy (b);
@@ -165,7 +165,7 @@ static void test_set_intersect_empty (void)
   hb_set_add (b, 0);
 
   hb_set_intersect (a, b);
-  g_assert (hb_set_is_empty (a));
+  g_assert_true (hb_set_is_empty (a));
 
   hb_set_destroy (a);
   hb_set_destroy (b);
@@ -183,7 +183,7 @@ static void test_set_intersect_page_reduction (void)
   hb_set_add (b, 24405);
 
   hb_set_intersect(a, b);
-  g_assert (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (a, b));
 
   hb_set_destroy (a);
   hb_set_destroy (b);
@@ -208,7 +208,7 @@ static void test_set_union (void)
   hb_set_add (u, 24405);
 
   hb_set_union(b, a);
-  g_assert (hb_set_is_equal (u, b));
+  g_assert_true (hb_set_is_equal (u, b));
 
   hb_set_destroy (a);
   hb_set_destroy (b);
@@ -223,24 +223,24 @@ test_set_subsets (void)
 
   hb_set_add (l, 0x0FFFF);
   hb_set_add (s, 0x1FFFF);
-  g_assert (!hb_set_is_subset (s, l));
+  g_assert_true (!hb_set_is_subset (s, l));
   hb_set_clear (s);
 
   hb_set_add (s, 0x0FFF0);
-  g_assert (!hb_set_is_subset (s, l));
+  g_assert_true (!hb_set_is_subset (s, l));
   hb_set_clear (s);
 
   hb_set_add (s, 0x0AFFF);
-  g_assert (!hb_set_is_subset (s, l));
+  g_assert_true (!hb_set_is_subset (s, l));
 
   hb_set_clear (s);
-  g_assert (hb_set_is_subset (s, l));
+  g_assert_true (hb_set_is_subset (s, l));
 
   hb_set_clear (l);
-  g_assert (hb_set_is_subset (s, l));
+  g_assert_true (hb_set_is_subset (s, l));
 
   hb_set_add (s, 0x1FFFF);
-  g_assert (!hb_set_is_subset (s, l));
+  g_assert_true (!hb_set_is_subset (s, l));
   hb_set_clear (s);
 
   hb_set_add (s, 0xFF);
@@ -251,17 +251,17 @@ test_set_subsets (void)
   hb_set_add (l, 0x1FFFF);
   hb_set_add (l, 0x2FFFF);
 
-  g_assert (hb_set_is_subset (s, l));
+  g_assert_true (hb_set_is_subset (s, l));
   hb_set_del (l, 0xFF);
-  g_assert (!hb_set_is_subset (s, l));
+  g_assert_true (!hb_set_is_subset (s, l));
   hb_set_add (l, 0xFF);
 
   hb_set_del (l, 0x2FFFF);
-  g_assert (!hb_set_is_subset (s, l));
+  g_assert_true (!hb_set_is_subset (s, l));
   hb_set_add (l, 0x2FFFF);
 
   hb_set_del (l, 0x1FFFF);
-  g_assert (!hb_set_is_subset (s, l));
+  g_assert_true (!hb_set_is_subset (s, l));
 
   hb_set_destroy (s);
   hb_set_destroy (l);
@@ -280,13 +280,13 @@ test_set_algebra (void)
   hb_set_add (o2, 0x660E);
 
   test_empty (s);
-  g_assert (!hb_set_is_equal (s, o));
-  g_assert (hb_set_is_subset (s, o));
-  g_assert (!hb_set_is_subset (o, s));
+  g_assert_true (!hb_set_is_equal (s, o));
+  g_assert_true (hb_set_is_subset (s, o));
+  g_assert_true (!hb_set_is_subset (o, s));
   hb_set_set (s, o);
-  g_assert (hb_set_is_equal (s, o));
-  g_assert (hb_set_is_subset (s, o));
-  g_assert (hb_set_is_subset (o, s));
+  g_assert_true (hb_set_is_equal (s, o));
+  g_assert_true (hb_set_is_subset (s, o));
+  g_assert_true (hb_set_is_subset (o, s));
   test_not_empty (s);
   g_assert_cmpint (hb_set_get_population (s), ==, 2);
 
@@ -296,50 +296,50 @@ test_set_algebra (void)
   g_assert_cmpint (hb_set_get_population (s), ==, 1);
   hb_set_union (s, o);
   g_assert_cmpint (hb_set_get_population (s), ==, 3);
-  g_assert (hb_set_has (s, 10));
-  g_assert (hb_set_has (s, 13));
+  g_assert_true (hb_set_has (s, 10));
+  g_assert_true (hb_set_has (s, 13));
 
   hb_set_clear (s);
   test_empty (s);
   g_assert_cmpint (hb_set_get_population (s), ==, 0);
   hb_set_union (s, o2);
   g_assert_cmpint (hb_set_get_population (s), ==, 1);
-  g_assert (hb_set_has (s, 0x660E));
+  g_assert_true (hb_set_has (s, 0x660E));
 
   hb_set_clear (s);
   test_empty (s);
   hb_set_add_range (s, 10, 17);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   hb_set_intersect (s, o);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   test_not_empty (s);
   g_assert_cmpint (hb_set_get_population (s), ==, 1);
-  g_assert (!hb_set_has (s, 10));
-  g_assert (hb_set_has (s, 13));
+  g_assert_true (!hb_set_has (s, 10));
+  g_assert_true (hb_set_has (s, 13));
 
   hb_set_clear (s);
   test_empty (s);
   hb_set_add_range (s, 10, 17);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   hb_set_subtract (s, o);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   test_not_empty (s);
   g_assert_cmpint (hb_set_get_population (s), ==, 7);
-  g_assert (hb_set_has (s, 12));
-  g_assert (!hb_set_has (s, 13));
-  g_assert (!hb_set_has (s, 19));
+  g_assert_true (hb_set_has (s, 12));
+  g_assert_true (!hb_set_has (s, 13));
+  g_assert_true (!hb_set_has (s, 19));
 
   hb_set_clear (s);
   test_empty (s);
   hb_set_add_range (s, 10, 17);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   hb_set_symmetric_difference (s, o);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   test_not_empty (s);
   g_assert_cmpint (hb_set_get_population (s), ==, 8);
-  g_assert (hb_set_has (s, 12));
-  g_assert (!hb_set_has (s, 13));
-  g_assert (hb_set_has (s, 19));
+  g_assert_true (hb_set_has (s, 12));
+  g_assert_true (!hb_set_has (s, 13));
+  g_assert_true (hb_set_has (s, 19));
 
   /* https://github.com/harfbuzz/harfbuzz/issues/579 */
   hb_set_clear (s);
@@ -351,25 +351,25 @@ test_set_algebra (void)
   test_empty (o);
   hb_set_add (o, 889);
   hb_set_add (o, 1024);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   hb_set_intersect (o, s);
   test_not_empty (o);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   g_assert_cmpint (hb_set_get_population (o), ==, 2);
-  g_assert (hb_set_has (o, 889));
-  g_assert (hb_set_has (o, 1024));
+  g_assert_true (hb_set_has (o, 889));
+  g_assert_true (hb_set_has (o, 1024));
   hb_set_clear (o);
   test_empty (o);
   hb_set_add_range (o, 887, 889);
   hb_set_add (o, 1121);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   hb_set_intersect (o, s);
   test_not_empty (o);
-  g_assert (!hb_set_is_equal (s, o));
+  g_assert_true (!hb_set_is_equal (s, o));
   g_assert_cmpint (hb_set_get_population (o), ==, 3);
-  g_assert (hb_set_has (o, 887));
-  g_assert (hb_set_has (o, 888));
-  g_assert (hb_set_has (o, 889));
+  g_assert_true (hb_set_has (o, 887));
+  g_assert_true (hb_set_has (o, 888));
+  g_assert_true (hb_set_has (o, 889));
 
   hb_set_clear (s);
   test_empty (s);
@@ -387,13 +387,13 @@ test_set_algebra (void)
   g_assert_cmpint (hb_set_get_population (o), ==, 1);
   hb_set_intersect (o, s);
   g_assert_cmpint (hb_set_get_population (o), ==, 1);
-  g_assert (hb_set_has (o, 889));
+  g_assert_true (hb_set_has (o, 889));
 
   hb_set_add (o, 511);
   g_assert_cmpint (hb_set_get_population (o), ==, 2);
   hb_set_intersect (o, s);
   g_assert_cmpint (hb_set_get_population (o), ==, 1);
-  g_assert (hb_set_has (o, 889));
+  g_assert_true (hb_set_has (o, 889));
 
   hb_set_destroy (s);
   hb_set_destroy (o);
@@ -416,84 +416,84 @@ test_set_iter (void)
   test_not_empty (s);
 
   next = HB_SET_VALUE_INVALID;
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, ==, 6);
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, ==, 10);
-  g_assert (hb_set_next (s, &next));
-  g_assert (hb_set_next (s, &next));
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, ==, 13);
-  g_assert (hb_set_next (s, &next));
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, ==, 15);
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, ==, 1100);
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, ==, 1200);
-  g_assert (hb_set_next (s, &next));
+  g_assert_true (hb_set_next (s, &next));
   g_assert_cmpint (next, ==, 20005);
-  g_assert (!hb_set_next (s, &next));
+  g_assert_true (!hb_set_next (s, &next));
   g_assert_cmpint (next, ==, HB_SET_VALUE_INVALID);
 
   next = HB_SET_VALUE_INVALID;
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, 20005);
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, 1200);
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, 1100);
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, 15);
-  g_assert (hb_set_previous (s, &next));
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, 13);
-  g_assert (hb_set_previous (s, &next));
-  g_assert (hb_set_previous (s, &next));
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, 10);
-  g_assert (hb_set_previous (s, &next));
+  g_assert_true (hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, 6);
-  g_assert (!hb_set_previous (s, &next));
+  g_assert_true (!hb_set_previous (s, &next));
   g_assert_cmpint (next, ==, HB_SET_VALUE_INVALID);
 
   first = last = HB_SET_VALUE_INVALID;
-  g_assert (hb_set_next_range (s, &first, &last));
+  g_assert_true (hb_set_next_range (s, &first, &last));
   g_assert_cmpint (first, ==, 6);
   g_assert_cmpint (last,  ==, 6);
-  g_assert (hb_set_next_range (s, &first, &last));
+  g_assert_true (hb_set_next_range (s, &first, &last));
   g_assert_cmpint (first, ==, 10);
   g_assert_cmpint (last,  ==, 15);
-  g_assert (hb_set_next_range (s, &first, &last));
+  g_assert_true (hb_set_next_range (s, &first, &last));
   g_assert_cmpint (first, ==, 1100);
   g_assert_cmpint (last,  ==, 1100);
-  g_assert (hb_set_next_range (s, &first, &last));
+  g_assert_true (hb_set_next_range (s, &first, &last));
   g_assert_cmpint (first, ==, 1200);
   g_assert_cmpint (last,  ==, 1200);
-  g_assert (hb_set_next_range (s, &first, &last));
+  g_assert_true (hb_set_next_range (s, &first, &last));
   g_assert_cmpint (first, ==, 20005);
   g_assert_cmpint (last,  ==, 20005);
-  g_assert (!hb_set_next_range (s, &first, &last));
+  g_assert_true (!hb_set_next_range (s, &first, &last));
   g_assert_cmpint (first, ==, HB_SET_VALUE_INVALID);
   g_assert_cmpint (last,  ==, HB_SET_VALUE_INVALID);
 
   first = last = HB_SET_VALUE_INVALID;
-  g_assert (hb_set_previous_range (s, &first, &last));
+  g_assert_true (hb_set_previous_range (s, &first, &last));
   g_assert_cmpint (first, ==, 20005);
   g_assert_cmpint (last,  ==, 20005);
-  g_assert (hb_set_previous_range (s, &first, &last));
+  g_assert_true (hb_set_previous_range (s, &first, &last));
   g_assert_cmpint (first, ==, 1200);
   g_assert_cmpint (last,  ==, 1200);
-  g_assert (hb_set_previous_range (s, &first, &last));
+  g_assert_true (hb_set_previous_range (s, &first, &last));
   g_assert_cmpint (first, ==, 1100);
   g_assert_cmpint (last,  ==, 1100);
-  g_assert (hb_set_previous_range (s, &first, &last));
+  g_assert_true (hb_set_previous_range (s, &first, &last));
   g_assert_cmpint (first, ==, 10);
   g_assert_cmpint (last,  ==, 15);
-  g_assert (hb_set_previous_range (s, &first, &last));
+  g_assert_true (hb_set_previous_range (s, &first, &last));
   g_assert_cmpint (first, ==, 6);
   g_assert_cmpint (last,  ==, 6);
-  g_assert (!hb_set_previous_range (s, &first, &last));
+  g_assert_true (!hb_set_previous_range (s, &first, &last));
   g_assert_cmpint (first, ==, HB_SET_VALUE_INVALID);
   g_assert_cmpint (last,  ==, HB_SET_VALUE_INVALID);
 
@@ -505,10 +505,10 @@ test_set_empty (void)
 {
   hb_set_t *b = hb_set_get_empty ();
 
-  g_assert (hb_set_get_empty ());
-  g_assert (hb_set_get_empty () == b);
+  g_assert_true (hb_set_get_empty ());
+  g_assert_true (hb_set_get_empty () == b);
 
-  g_assert (!hb_set_allocation_successful (b));
+  g_assert_true (!hb_set_allocation_successful (b));
 
   test_empty (b);
 
@@ -516,13 +516,13 @@ test_set_empty (void)
 
   test_empty (b);
 
-  g_assert (!hb_set_allocation_successful (b));
+  g_assert_true (!hb_set_allocation_successful (b));
 
   hb_set_clear (b);
 
   test_empty (b);
 
-  g_assert (!hb_set_allocation_successful (b));
+  g_assert_true (!hb_set_allocation_successful (b));
 
   hb_set_destroy (b);
 }
@@ -565,10 +565,10 @@ test_set_delrange (void)
   {
     unsigned b = ranges[i].b;
     unsigned e = ranges[i].e;
-    g_assert (hb_set_has (s, (b-2)&~1));
+    g_assert_true (hb_set_has (s, (b-2)&~1));
     while (b <= e)
-      g_assert (!hb_set_has (s, b++));
-    g_assert (hb_set_has (s, (e+2)&~1));
+      g_assert_true (!hb_set_has (s, b++));
+    g_assert_true (hb_set_has (s, (e+2)&~1));
   }
 
   hb_set_destroy (s);
@@ -586,29 +586,29 @@ test_set_inverted_basics (void)
   hb_set_invert (s);
 
   g_assert_cmpint (hb_set_get_population (s), ==, max_set_elements);
-  g_assert (hb_set_has (s, 0));
-  g_assert (hb_set_has (s, 13));
-  g_assert (hb_set_has (s, max_set_elements - 1));
-  g_assert (!hb_set_is_empty (s));
+  g_assert_true (hb_set_has (s, 0));
+  g_assert_true (hb_set_has (s, 13));
+  g_assert_true (hb_set_has (s, max_set_elements - 1));
+  g_assert_true (!hb_set_is_empty (s));
   g_assert_cmpint (hb_set_get_min (s), ==, 0);
   g_assert_cmpint (hb_set_get_max (s), ==, max_set_elements - 1);
 
   hb_set_del (s, 13);
-  g_assert (!hb_set_has (s, 13));
+  g_assert_true (!hb_set_has (s, 13));
   g_assert_cmpint (hb_set_get_population (s), ==, max_set_elements - 1);
   g_assert_cmpint (hb_set_get_min (s), ==, 0);
   g_assert_cmpint (hb_set_get_max (s), ==, max_set_elements - 1);
 
   hb_set_add (s, 13);
-  g_assert (hb_set_has (s, 13));
+  g_assert_true (hb_set_has (s, 13));
   g_assert_cmpint (hb_set_get_population (s), ==, max_set_elements);
 
   hb_set_del (s, 0);
   hb_set_del (s, max_set_elements - 1);
-  g_assert (!hb_set_has (s, 0));
-  g_assert (hb_set_has (s, 13));
-  g_assert (!hb_set_has (s, max_set_elements - 1));
-  g_assert (!hb_set_is_empty (s));
+  g_assert_true (!hb_set_has (s, 0));
+  g_assert_true (hb_set_has (s, 13));
+  g_assert_true (!hb_set_has (s, max_set_elements - 1));
+  g_assert_true (!hb_set_is_empty (s));
   g_assert_cmpint (hb_set_get_population (s), ==, max_set_elements - 2);
   g_assert_cmpint (hb_set_get_min (s), ==, 1);
   g_assert_cmpint (hb_set_get_max (s), ==, max_set_elements - 2);
@@ -628,39 +628,39 @@ test_set_inverted_ranges (void)
   hb_set_del_range (s, 41, 4000);
   hb_set_add_range (s, 78, 601);
 
-  g_assert (hb_set_has (s, 40));
-  g_assert (!hb_set_has (s, 41));
-  g_assert (!hb_set_has (s, 64));
-  g_assert (!hb_set_has (s, 77));
-  g_assert (hb_set_has (s, 78));
-  g_assert (hb_set_has (s, 300));
-  g_assert (hb_set_has (s, 601));
-  g_assert (!hb_set_has (s, 602));
-  g_assert (!hb_set_has (s, 3000));
-  g_assert (!hb_set_has (s, 4000));
-  g_assert (hb_set_has (s, 4001));
+  g_assert_true (hb_set_has (s, 40));
+  g_assert_true (!hb_set_has (s, 41));
+  g_assert_true (!hb_set_has (s, 64));
+  g_assert_true (!hb_set_has (s, 77));
+  g_assert_true (hb_set_has (s, 78));
+  g_assert_true (hb_set_has (s, 300));
+  g_assert_true (hb_set_has (s, 601));
+  g_assert_true (!hb_set_has (s, 602));
+  g_assert_true (!hb_set_has (s, 3000));
+  g_assert_true (!hb_set_has (s, 4000));
+  g_assert_true (hb_set_has (s, 4001));
 
-  g_assert (!hb_set_is_empty (s));
+  g_assert_true (!hb_set_is_empty (s));
   g_assert_cmpint (hb_set_get_population (s), ==, max_set_elements - 3436);
   g_assert_cmpint (hb_set_get_min (s), ==, 0);
   g_assert_cmpint (hb_set_get_max (s), ==, max_set_elements - 1);
 
   hb_set_del_range (s, 0, 37);
-  g_assert (!hb_set_has (s, 0));
-  g_assert (!hb_set_has (s, 37));
-  g_assert (hb_set_has (s, 38));
-  g_assert (!hb_set_is_empty (s));
+  g_assert_true (!hb_set_has (s, 0));
+  g_assert_true (!hb_set_has (s, 37));
+  g_assert_true (hb_set_has (s, 38));
+  g_assert_true (!hb_set_is_empty (s));
   g_assert_cmpint (hb_set_get_population (s), ==,
                    max_set_elements - 3436 - 38);
   g_assert_cmpint (hb_set_get_min (s), ==, 38);
   g_assert_cmpint (hb_set_get_max (s), ==, max_set_elements - 1);
 
   hb_set_del_range (s, max_set_elements - 13, max_set_elements - 1);
-  g_assert (!hb_set_has (s, max_set_elements - 1));
-  g_assert (!hb_set_has (s, max_set_elements - 13));
-  g_assert (hb_set_has (s, max_set_elements - 14));
+  g_assert_true (!hb_set_has (s, max_set_elements - 1));
+  g_assert_true (!hb_set_has (s, max_set_elements - 13));
+  g_assert_true (hb_set_has (s, max_set_elements - 14));
 
-  g_assert (!hb_set_is_empty (s));
+  g_assert_true (!hb_set_is_empty (s));
   g_assert_cmpint (hb_set_get_population (s), ==,
                    max_set_elements - 3436 - 38 - 13);
   g_assert_cmpint (hb_set_get_min (s), ==, 38);
@@ -683,90 +683,90 @@ test_set_inverted_iteration_next (void)
   hb_codepoint_t cp = HB_SET_VALUE_INVALID;
   hb_codepoint_t start = 0;
   hb_codepoint_t end = 0;
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 0);
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 1);
 
-  g_assert (hb_set_next_range (s, &start, &end));
+  g_assert_true (hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, 1);
   g_assert_cmpint (end, ==, 40);
 
   start = 40;
   end = 40;
-  g_assert (hb_set_next_range (s, &start, &end));
+  g_assert_true (hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, 78);
   g_assert_cmpint (end, ==, 601);
 
   start = 40;
   end = 57;
-  g_assert (hb_set_next_range (s, &start, &end));
+  g_assert_true (hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, 78);
   g_assert_cmpint (end, ==, 601);
 
   cp = 39;
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 40);
 
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 78);
 
   cp = 56;
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 78);
 
   cp = 78;
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 79);
 
   cp = 601;
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 4001);
 
   cp = HB_SET_VALUE_INVALID;
   hb_set_del (s, 0);
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, 1);
 
   start = 0;
   end = 0;
-  g_assert (hb_set_next_range (s, &start, &end));
+  g_assert_true (hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, 1);
   g_assert_cmpint (end, ==, 40);
 
   cp = max_set_elements - 1;
-  g_assert (!hb_set_next (s, &cp));
+  g_assert_true (!hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, HB_SET_VALUE_INVALID);
 
   start = 4000;
   end = 4000;
-  g_assert (hb_set_next_range (s, &start, &end));
+  g_assert_true (hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, 4001);
   g_assert_cmpint (end, ==, max_set_elements - 1);
 
   start = max_set_elements - 1;
   end = max_set_elements - 1;
-  g_assert (!hb_set_next_range (s, &start, &end));
+  g_assert_true (!hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, HB_SET_VALUE_INVALID);
   g_assert_cmpint (end, ==, HB_SET_VALUE_INVALID);
 
   cp = max_set_elements - 3;
   hb_set_del (s, max_set_elements - 1);
-  g_assert (hb_set_next (s, &cp));
+  g_assert_true (hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, max_set_elements - 2);
-  g_assert (!hb_set_next (s, &cp));
+  g_assert_true (!hb_set_next (s, &cp));
   g_assert_cmpint (cp, ==, HB_SET_VALUE_INVALID);
 
 
   start = max_set_elements - 2;
   end = max_set_elements - 2;
-  g_assert (!hb_set_next_range (s, &start, &end));
+  g_assert_true (!hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, HB_SET_VALUE_INVALID);
   g_assert_cmpint (end, ==, HB_SET_VALUE_INVALID);
 
   start = max_set_elements - 3;
   end = max_set_elements - 3;
-  g_assert (hb_set_next_range (s, &start, &end));
+  g_assert_true (hb_set_next_range (s, &start, &end));
   g_assert_cmpint (start, ==, max_set_elements - 2);
   g_assert_cmpint (end, ==, max_set_elements - 2);
 
@@ -787,94 +787,94 @@ test_set_inverted_iteration_prev (void)
   hb_codepoint_t cp = HB_SET_VALUE_INVALID;
   hb_codepoint_t start = max_set_elements - 1;
   hb_codepoint_t end = max_set_elements - 1;
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, max_set_elements - 1);
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, max_set_elements - 2);
 
-  g_assert (hb_set_previous_range (s, &start, &end));
+  g_assert_true (hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, 4001);
   g_assert_cmpint (end, ==, max_set_elements - 2);
 
   start = 4001;
   end = 4001;
-  g_assert (hb_set_previous_range (s, &start, &end));
+  g_assert_true (hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, 78);
   g_assert_cmpint (end, ==, 601);
 
   start = 2500;
   end = 3000;
-  g_assert (hb_set_previous_range (s, &start, &end));
+  g_assert_true (hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, 78);
   g_assert_cmpint (end, ==, 601);
 
   cp = 4002;
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, 4001);
 
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, 601);
 
   cp = 3500;
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, 601);
 
   cp = 601;
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, 600);
 
   cp = 78;
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, 40);
 
   cp = HB_SET_VALUE_INVALID;
   hb_set_del (s, max_set_elements - 1);
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, max_set_elements - 2);
 
   start = max_set_elements - 1;
   end = max_set_elements - 1;
-  g_assert (hb_set_previous_range (s, &start, &end));
+  g_assert_true (hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, 4001);
   g_assert_cmpint (end, ==, max_set_elements - 2);
 
   cp = 0;
-  g_assert (!hb_set_previous (s, &cp));
+  g_assert_true (!hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, HB_SET_VALUE_INVALID);
 
   cp = 40;
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, 39);
 
   start = 40;
   end = 40;
-  g_assert (hb_set_previous_range (s, &start, &end));
+  g_assert_true (hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, 0);
   g_assert_cmpint (end, ==, 39);
 
   start = 0;
   end = 0;
-  g_assert (!hb_set_previous_range (s, &start, &end));
+  g_assert_true (!hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, HB_SET_VALUE_INVALID);
   g_assert_cmpint (end, ==, HB_SET_VALUE_INVALID);
 
 
   cp = 2;
   hb_set_del (s, 0);
-  g_assert (hb_set_previous (s, &cp));
+  g_assert_true (hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, 1);
-  g_assert (!hb_set_previous (s, &cp));
+  g_assert_true (!hb_set_previous (s, &cp));
   g_assert_cmpint (cp, ==, HB_SET_VALUE_INVALID);
 
   start = 1;
   end = 1;
-  g_assert (!hb_set_previous_range (s, &start, &end));
+  g_assert_true (!hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, HB_SET_VALUE_INVALID);
   g_assert_cmpint (end, ==, HB_SET_VALUE_INVALID);
 
   start = 2;
   end = 2;
-  g_assert (hb_set_previous_range (s, &start, &end));
+  g_assert_true (hb_set_previous_range (s, &start, &end));
   g_assert_cmpint (start, ==, 1);
   g_assert_cmpint (end, ==, 1);
 
@@ -890,50 +890,50 @@ test_set_inverted_equality (void)
   hb_set_invert (a);
   hb_set_invert (b);
 
-  g_assert (hb_set_is_equal (a, b));
-  g_assert (hb_set_is_equal (b, a));
+  g_assert_true (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (b, a));
 
   hb_set_add (a, 10);
-  g_assert (hb_set_is_equal (a, b));
-  g_assert (hb_set_is_equal (b, a));
+  g_assert_true (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (b, a));
 
   hb_set_del (a, 42);
-  g_assert (!hb_set_is_equal (a, b));
-  g_assert (!hb_set_is_equal (b, a));
+  g_assert_true (!hb_set_is_equal (a, b));
+  g_assert_true (!hb_set_is_equal (b, a));
 
   hb_set_del (b, 42);
-  g_assert (hb_set_is_equal (a, b));
-  g_assert (hb_set_is_equal (b, a));
+  g_assert_true (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (b, a));
 
   hb_set_del_range (a, 43, 50);
   hb_set_del_range (a, 51, 76);
   hb_set_del_range (b, 43, 76);
-  g_assert (hb_set_is_equal (a, b));
-  g_assert (hb_set_is_equal (b, a));
+  g_assert_true (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (b, a));
 
   hb_set_del (a, 0);
-  g_assert (!hb_set_is_equal (a, b));
-  g_assert (!hb_set_is_equal (b, a));
+  g_assert_true (!hb_set_is_equal (a, b));
+  g_assert_true (!hb_set_is_equal (b, a));
 
   hb_set_del (b, 0);
-  g_assert (hb_set_is_equal (a, b));
-  g_assert (hb_set_is_equal (b, a));
+  g_assert_true (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (b, a));
 
   hb_set_del (a, max_set_elements - 1);
-  g_assert (!hb_set_is_equal (a, b));
-  g_assert (!hb_set_is_equal (b, a));
+  g_assert_true (!hb_set_is_equal (a, b));
+  g_assert_true (!hb_set_is_equal (b, a));
 
   hb_set_del (b, max_set_elements - 1);
-  g_assert (hb_set_is_equal (a, b));
-  g_assert (hb_set_is_equal (b, a));
+  g_assert_true (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (b, a));
 
   hb_set_invert (a);
-  g_assert (!hb_set_is_equal (a, b));
-  g_assert (!hb_set_is_equal (b, a));
+  g_assert_true (!hb_set_is_equal (a, b));
+  g_assert_true (!hb_set_is_equal (b, a));
 
   hb_set_invert (b);
-  g_assert (hb_set_is_equal (a, b));
-  g_assert (hb_set_is_equal (b, a));
+  g_assert_true (hb_set_is_equal (a, b));
+  g_assert_true (hb_set_is_equal (b, a));
 
   hb_set_destroy (a);
   hb_set_destroy (b);
@@ -1018,18 +1018,19 @@ check_set_operations(hb_bool_t a_has_x,
     break;
   }
 
-  printf ("%s%s%s%s %-9s %s%s%s%s == %s  [%s]\n",
-          a_inverted ? "i" : " ",
-          a_has_page ? "p" : " ",
-          a_is_null ? "n" : " ",
-          a_has_x ? "{13}" : "{}  ",
-          op_name,
-          b_inverted ? "i" : " ",
-          b_has_page ? "p" : " ",
-          b_is_null ? "n" : " ",
-          b_has_x ? "{13}" : "{}  ",
-          should_have_x ? "{13}" : "{}  ",
-          has_expected ? "succeeded" : "failed");
+  if (FALSE)
+    printf ("%s%s%s%s %-9s %s%s%s%s == %s  [%s]\n",
+	    a_inverted ? "i" : " ",
+	    a_has_page ? "p" : " ",
+	    a_is_null ? "n" : " ",
+	    a_has_x ? "{13}" : "{}  ",
+	    op_name,
+	    b_inverted ? "i" : " ",
+	    b_has_page ? "p" : " ",
+	    b_is_null ? "n" : " ",
+	    b_has_x ? "{13}" : "{}  ",
+	    should_have_x ? "{13}" : "{}  ",
+	    has_expected ? "succeeded" : "failed");
 
   hb_set_destroy (a);
   hb_set_destroy (b);
@@ -1064,7 +1065,7 @@ test_set_inverted_operations (void)
     }
   }
 
-  g_assert (all_succeeded);
+  g_assert_true (all_succeeded);
 }
 
 static void
@@ -1074,13 +1075,13 @@ test_hb_set_add_sorted_array (void)
   hb_codepoint_t array[7] = {1, 2, 3, 1000, 2000, 2001, 2002};
   hb_set_add_sorted_array (set, array, 7);
   g_assert_cmpint (hb_set_get_population (set), ==, 7);
-  g_assert (hb_set_has (set, 1));
-  g_assert (hb_set_has (set, 2));
-  g_assert (hb_set_has (set, 3));
-  g_assert (hb_set_has (set, 1000));
-  g_assert (hb_set_has (set, 2000));
-  g_assert (hb_set_has (set, 2001));
-  g_assert (hb_set_has (set, 2002));
+  g_assert_true (hb_set_has (set, 1));
+  g_assert_true (hb_set_has (set, 2));
+  g_assert_true (hb_set_has (set, 3));
+  g_assert_true (hb_set_has (set, 1000));
+  g_assert_true (hb_set_has (set, 2000));
+  g_assert_true (hb_set_has (set, 2001));
+  g_assert_true (hb_set_has (set, 2002));
   hb_set_destroy (set);
 }
 
@@ -1092,7 +1093,7 @@ test_set_next_many (void)
     hb_set_add (set, i);
   for (unsigned i=6000; i<6100; i++)
     hb_set_add (set, i);
-  g_assert (hb_set_get_population (set) == 700);
+  g_assert_true (hb_set_get_population (set) == 700);
   hb_codepoint_t array[700];
 
   unsigned int n = hb_set_next_many (set, HB_SET_VALUE_INVALID, array, 700);
@@ -1101,7 +1102,7 @@ test_set_next_many (void)
   for (unsigned i=0; i<600; i++)
     g_assert_cmpint (array[i], ==, i);
   for (unsigned i=0; i<100; i++)
-    g_assert (array[600 + i] == 6000u + i);
+    g_assert_true (array[600 + i] == 6000u + i);
 
   // Try skipping initial values.
   for (unsigned i = 0; i < 700; i++)
@@ -1124,7 +1125,7 @@ test_set_next_many_restricted (void)
     hb_set_add (set, i);
   for (int i=6000; i<6100; i++)
     hb_set_add (set, i);
-  g_assert (hb_set_get_population (set) == 700);
+  g_assert_true (hb_set_get_population (set) == 700);
   hb_codepoint_t array[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
   hb_set_next_many (set, HB_SET_VALUE_INVALID, array, 9);
